*Set up workspace
set more off

/**********************************************************************************************************
* Load MRP data and rename variables; encode FIPS as real. The MRP estimates take place separately in R
**********************************************************************************************************/

use data/CountySocialReturnsMrPEstimates.dta
gen temp=real(fipsindx )
drop fipsindx
rename temp fipsindx

foreach var of varlist recode_cr46 recode_cr47 recode_cr48 recode_cr49 {
 rename `var' mrp_`var'
 
 }

label var mrp_recode_cr46 "MRP People I know vote (0-1)"
label var mrp_recode_cr47 "MRP Family and friends disappointed if I don't vote (0-1)"
label var mrp_recode_cr48 "MRP If I do not vote, I feel guilty (0-1)"
label var mrp_recode_cr49 "MRP If I do not vote, I feel less American (0-1)" 
 
sort fipsindx
save data/CountySocialReturnsMrPEstimates_cleaned.dta, replace
clear

/**********************************************************************************************************
* Collapse to county-level averages and merge in all other county-level summary measures/outcomes
**********************************************************************************************************/

use data/NAESRecoded.dta

*Get rid of survey measures other than county and recoded survey meaures.
keep fipsindx recode_cr* 

*Save the variable and value labels for later collapse
foreach var of varlist * {
 local templbl`var' : variable label `var'
}

***Collapsed to counties***
collapse (mean) recode_cr46 recode_cr47 recode_cr48 recode_cr49 (count) numobs=recode_cr46, by(fipsindx)
*restore variable labels
foreach var of varlist * {
 label variable `var' "`templbl`var''"
}

*State indicators--state code is first two digits of county code
gen state=int(fipsindx/1000)
quietly tab state, gen(sd_)
drop sd_4

joinby fipsindx using "..\..\NotInReplicationArchive\countyreligionestimates.dta", unmatched(master)
rename _merge relig_merge

*Fix county code for Miami-dade to make merge work
*update FIPS code: Miami-Dade County changed from 12025 to 12086 in 1999, but NAES uses old number
replace fipsindx=12086 if fipsindx==12025
joinby fipsindx using "..\..\NotInReplicationArchive\fipsindx_to_countyinfofromusacounties.dta", unmatched(master)
count
replace fipsindx=12025 if fipsindx==12086
rename _merge usacounties_merge

** South Boston, VA (51780) merged with Halifax County, VA (51083) in 1995
replace fipsindx=51083 if fipsindx==51780 
replace fipsindx=12086 if fipsindx==12025

*Merge in datasets that use new FIPS codes
**2000 county-level vote totals from http://www.uselectionatlas.org/  David Leip 2001 All Rights Reserved
count
joinby fipsindx using "..\..\NotInReplicationArchive\2000 County Turnout.dta", unmatched(master)
count
rename _merge vote_merge

**2000 county-level voting-age population estimates obtained from http://factfinder.census.gov/servlet/DCGeoSelectServlet?ds_name=DEC_2000_SF1_U
count
joinby fipsindx using "..\..\NotInReplicationArchive\CountyPopbyAge2000.dta", unmatched(master)
count
rename _merge pop_merge

**2005-2009 citizen voting-age population estimates from http://www.census.gov/rdo/data/voting_age_population_by_citizenship_and_race_cvap.html
count
joinby fipsindx using "..\..\NotInReplicationArchive\CountyCVAP2005-2009.dta", unmatched(master)
count
rename _merge cvap_merge
*Note: We lose one observation here: Clifton Forge City, which is no longer an independent city as of 2001.
count

*Generate county turnout proportion
gen popturnout00 = totalvote00/census2000pop
label variable popturnout00 "Proportion of county population voting in 2000 election"

gen vapturnout00 = totalvote00/vap
label variable vapturnout00 "Proportion of county voting-age population voting in 2000 election"

gen cvap05turnout00 = totalvote00/cvap_est
label variable cvap05turnout00 "Proportion of county voting in 2000 election based on 2005-2009 citizen voting-age population"

/* Merge in MRP estimates */
joinby fipsindx using "data\CountySocialReturnsMrPEstimates_cleaned.dta"
/* All done */

save "data\CountyCollapsedNAESMrPDemographics.dta", replace


