*Set up workspace
set more off

**************************************
* Conduct appendix individual-level analysis for appendix
**************************************

use data/NAESRecoded.dta

*standardize norms measure
foreach var of varlist recode_cr47 {
 egen temp=std(`var')
 drop `var'
 rename temp `var'
 }

label var recode_cr47 "Family and friends disappointed if I don't vote (M=0, SD=1)"

regress voted recode_cr47 d_* f_* pidcat*, robust cluster(state)
outreg using "Tables\AppendixIndividualLevelAnalysis.out", se bracket rdec(6) 3aster replace ctitle("Own Reported Turnout")

summ voted if e(sample)

xtreg voted recode_cr47 d_* f_* pidcat*, robust i(fipsindx)
outreg using "Tables\AppendixIndividualLevelAnalysis.out", se bracket rdec(6) 3aster append ctitle("Own Reported Turnout, County fixed effects")
clear

**************************************
* Conduct county-level analysis, main text
**************************************

use "data\CountyCollapsedNAESMrPDemographics.dta"

*Define dependent variable
local dv "vapturnout00"

*Restrict sample to cases without missing data
local controlvars "d_* mempercap"
qui regress `dv' `controlvars' recode_cr46 recode_cr47 recode_cr48 recode_cr49
keep if e(sample)
count

gen wtsqrtn=sqrt(numobs)

qui tab state, gen(stfe_)
qui drop stfe_1

replace d_medianhhinc = d_medianhhinc /1000
label var d_medianhhinc "Median HH Income (in $1,000s, 2000)"
replace d_fedexppci = d_fedexppci /1000
label var d_medianhhinc "Per Capita Federal Expenditures (in $1,000s, 2000)"
replace d_pci = d_pci /1000
label var d_pci "Per Capita Income (in $1,000s, 2000)"

*Before going any further, standardize all norms measures.
foreach var of varlist recode_cr46 recode_cr47 recode_cr48 recode_cr49 mrp_recode_cr46 mrp_recode_cr47 mrp_recode_cr48 mrp_recode_cr49 {
 egen temp=std(`var')
 drop `var'
 rename temp `var'
 }

label var recode_cr46 "People I know vote (M=0, SD=1)"
label var recode_cr47 "Family and friends disappointed if I don't vote (M=0, SD=1)"
label var recode_cr48 "If I do not vote, I feel guilty (M=0, SD=1)"
label var recode_cr49 "If I do not vote, I feel less American (M=0, SD=1)"

label var mrp_recode_cr46 "MRP People I know vote (M=0, SD=1)"
label var mrp_recode_cr47 "MRP Family and friends disappointed if I don't vote (M=0, SD=1)"
label var mrp_recode_cr48 "MRP If I do not vote, I feel guilty (M=0, SD=1)"
label var mrp_recode_cr49 "MRP If I do not vote, I feel less American (M=0, SD=1)" 

*Set common sample across all models
qui regress `dv' recode_cr47 recode_cr48 mrp_recode_cr47 mrp_recode_cr48 `controlvars'
keep if e(sample)

* Outsum doesn't work in some new versions of stata. This is just putting the summary statistics into column (0) of the regression output table.
cap outsum `dv' recode_cr47 mrp_recode_cr47 `controlvars' using Tables\Table4CountyLevelAnalysis, bracket replace ctitle("Summary Statistics, All counties")

*This is the analysis without any effort to deal with measurement error
regress `dv' recode_cr47 `controlvars', robust cluster(state)
outreg using "Tables\Table4CountyLevelAnalysis", se bracket rdec(6) 3aster append ctitle("VAP Turnout, County-collapsed, unweighted")

*Weighting by sqrt # obs in county
regress `dv' recode_cr47 `controlvars' [aweight=wtsqrtn], robust cluster(state)
outreg using "Tables\Table4CountyLevelAnalysis", se bracket rdec(6) 3aster append ctitle("County-collapsed, weight by sqrt(county obs)")

*Using MRP
regress `dv' mrp_recode_cr47 `controlvars' , robust cluster(state)
outreg using "Tables\Table4CountyLevelAnalysis", se bracket rdec(6) 3aster append ctitle("County-collapsed, MRP")

*Now need to set sample for state-fixed effects analysis. This means restricting to cases with more than one observation per state
qui regress `dv' recode_cr47 `controlvars' stfe_* [aweight=wtsqrtn], robust cluster(state)
egen obsperstate=count(`dv') if e(sample), by(state)

*State fixed effects, weighting by sqrt # obs in county
regress `dv' recode_cr47 `controlvars' stfe_* [aweight=wtsqrtn] if obsperstate>1, robust cluster(state)
test recode_cr47
outreg using "Tables\Table4CountyLevelAnalysis", se bracket rdec(6) 3aster append ctitle("County-collapsed, state FE, weight by sqrt(county obs)")

*State fixed effects, using MRP
regress `dv' mrp_recode_cr47 `controlvars' stfe_* if obsperstate>1, robust cluster(state)
outreg using "Tables\Table4CountyLevelAnalysis", se bracket rdec(6) 3aster append ctitle("County-collapsed, state FE, MRP")

*Now need to set sample for state-fe analysis with counties with more than 5 observations. This means restricting to cases with more than one observation per state after that restriction
drop obsperstate
qui regress `dv' recode_cr47 `controlvars' stfe_* [aweight=wtsqrtn] if numobs>=5, robust cluster(state)
egen obsperstate=count(`dv') if e(sample), by(state)

regress `dv' recode_cr47 `controlvars' stfe_* if numobs>=5 & obsperstate>1, robust cluster(state)
outreg using "Tables\Table4CountyLevelAnalysis", se bracket rdec(6) 3aster append ctitle("County-collapsed, state FE, unweighted, all counties with 5+ obs.")

regress `dv' mrp_recode_cr47 `controlvars' stfe_* if numobs>=5 & obsperstate>1, robust cluster(state)
outreg using "Tables\Table4CountyLevelAnalysis", se bracket rdec(6) 3aster append ctitle("County-collapsed, state FE, unweighted, MRP, all counties with 5+ obs.")



