********************************************
**SOCIAL RETURNS TO EXPERIMENT - 2009 CCES**
********************************************
set more off

use data\cces09_replication.dta, clear

*** DEMOGRAPHICS
gen weight=v200
gen race=v211
tab race, gen(r_)
rename r_1 r_white
rename r_2 r_black
rename r_3 r_hispanic
gen r_other=r_4+r_5+r_6+r_7+r_8
label var r_other "Other race=1"
label var r_white "White = 1"
label var r_black "Black = 1"
label var r_hispanic "Hispanic = 1"

gen age=v288
gen age2=(age^2)/100

label var age "Age (in years)"
label var age2 "Age-squared/100"

recode v208 (1=0) (2=1) (*=.), gen(female)
label var female "Female=1"

recode cc424 (1=-3) (2=-2) (3=-1) (4 8=0) (5=1) (6=2) (7=3) (*=.), gen(pid)
recode pid (-3/-1=-1) (1/3=1) (0=0) (*=.), gen(pid3)
recode v261 (1=-2) (2=-1) (3 6=0) (4=1) (5=2) (*=.), gen(ideol)
label var pid "Party ID (-3=S. Dem; 3=S. Rep)"
label var pid3 "Party ID (-1=Dem; 1=Rep)"
label var ideol "Ideology (-2=V. Lib; 2=V. Cons)"
tab pid, gen(pidD)
drop pidD4
tab ideol, gen(ideolD)
drop ideolD3
label var pidD1 "Party ID = Strong Democrat"
label var pidD2 "Party ID = Weak Democrat"
label var pidD3 "Party ID = Lean Democrat"
label var pidD5 "Party ID = Lean Republican"
label var pidD6 "Party ID = Weak Republican"
label var pidD7 "Party ID = Strong Republican"

label var ideolD1 "Ideology = Very Liberal"
label var ideolD2 "Ideology = Liberal"
label var ideolD4 "Ideology = Conservative"
label var ideolD5 "Ideology = Very Conservative"


recode v217 (1=6) (2=5) (3=4) (4=3) (5=2) (6=1) (*=.), gen(religatt)
label var religatt "Religious Attendance (1 never;6 more than 1/week)"

recode v244 (1=4) (2=3) (3=2) (4=1) (*=.), gen(interest)
label var interest "Political Interest (1 hardly at all; 4 most of the time)"

recode yal125 (1=3) (2=2) (3=1) (4=0) (*=.), gen(trustgov)
label var trustgov "Trust Government? (0=never; 3=always)"

recode yala50 (2=0) (8=.), gen(dutyvote)

recode v213 (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (*=.), gen(educ)
label var educ "Education (1=No HS; 6=post-grad)"
tab educ, gen(educD)
drop educD2

recode v246 (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (7=7) (8=8) (9=9) (10=10) (11=11) (12=12) (13=13) (14=14) (15=15) (*=.), gen(income)
label var income "Income (1=<$10k; 14=>150k; 15=RF)"
gen income2=income^2
label var income2 "Income-squared"
gen incomemis=(income==15)
label var incomemis "Income Missing"

******* OUTCOMES *******
foreach i in 22 23 24 25 97 98 99 100{
if `i'==22 | `i'==97 {
local c=1
}
else{
local c=`c'+1
}
if `i'<30{
gen sr_vign_`c'_impress=yala`i'b
gen sr_vign_`c'_responsible=yala`i'd
gen sr_vign_`c'_respect=yala`i'e
}
else{
gen sr_single_`c'_impress=yala`i'b
gen sr_single_`c'_responsible=yala`i'd
gen sr_single_`c'_respect=yala`i'e
}
}

recode sr_vign* sr_single* (1=3) (2=2) (3=1) (4=0) (5=-1) (6=-2) (7=-3) (*=.)
forvalues i=1/4{
gen sr_vign_`i'_summary=(sr_vign_`i'_impress+sr_vign_`i'_responsible+sr_vign_`i'_respect)/3
gen sr_single_`i'_summary=(sr_single_`i'_impress+sr_single_`i'_responsible+sr_single_`i'_respect)/3

label var sr_vign_`i'_impress "Vignette `i': Postive Impression (-3=St. Disagree;3=St. Agree)"
label var sr_vign_`i'_responsible "Vignette `i': Is Responsible (-3=St. Disagree;3=St. Agree)"
label var sr_vign_`i'_respect "Vignette `i': I Respect (-3=St. Disagree;3=St. Agree)"
label var sr_vign_`i'_summary "Vignette `i': I Respect (-3=St. Disagree;3=St. Agree)"
label var sr_single_`i'_impress "Single Phrase `i': Postive Impression (-3=St. Disagree;3=St. Agree)"
label var sr_single_`i'_responsible "Single Phrase `i': Is Responsible (-3=St. Disagree;3=St. Agree)"
label var sr_single_`i'_respect "Single Phrase `i': I Respect (-3=St. Disagree;3=St. Agree)"
}

** VIGNETTE TREATMENTS ** 
tab educ22, gen(sr_vign_1_t_educ)
drop sr_vign_1_t_educ2
rename sr_vign_1_t_educ1 sr_vign_1_t_educ
label var sr_vign_1_t_educ "Education (1=College degree; 0=HS diploma)"

tab tax22, gen(sr_vign_1_t_tax)
drop sr_vign_1_t_tax1
rename sr_vign_1_t_tax2 sr_vign_1_t_tax
label var sr_vign_1_t_tax "Pays Taxes (1=On time; 0=Late)"

tab current23, gen(sr_vign_2_t_current)
drop sr_vign_2_t_current1
rename sr_vign_2_t_current2 sr_vign_2_t_current
label var sr_vign_2_t_current "Current Events (1=Stays informed; 0=Does not stay informed)"

tab litter23, gen(sr_vign_2_t_recycle)
drop sr_vign_2_t_recycle1
rename sr_vign_2_t_recycle2 sr_vign_2_t_recycle
label var sr_vign_2_t_recycle "Recycles (1=yes; 0=no)"

forvalues i=22/23{
local a=`i'-21

tab vote`i', mis gen(sr_vign_`a'_t_vote)
drop sr_vign_`a'_t_vote1 
rename sr_vign_`a'_t_vote2 sr_vign_`a'_t_always
rename sr_vign_`a'_t_vote3 sr_vign_`a'_t_never
rename sr_vign_`a'_t_vote4 sr_vign_`a'_t_usually 
label var sr_vign_`a'_t_always "Vote (1=Always)"
label var sr_vign_`a'_t_never "Vote (1=Never)"
label var sr_vign_`a'_t_usually "Vote (1=Usually)"
}

tab educ24, gen(sr_vign_3_t_educ)
drop sr_vign_3_t_educ2
rename sr_vign_3_t_educ1 sr_vign_3_t_educ
label var sr_vign_3_t_educ "Education (1=College degree; 0=HS diploma)"

tab charity24, gen(sr_vign_3_t_volunteer)
drop sr_vign_3_t_volunteer1
rename sr_vign_3_t_volunteer2 sr_vign_3_t_volunteer
label var sr_vign_3_t_volunteer "Volunteer in Community (1=yes; 0=no)"

tab book25, gen(sr_vign_4_t_books)
drop sr_vign_4_t_books1
rename sr_vign_4_t_books2 sr_vign_4_t_books
label var sr_vign_4_t_books "Library books (1=Return on time; 0=Return late)"

tab educ25, gen(sr_vign_4_t_educ)
drop sr_vign_4_t_educ2
rename sr_vign_4_t_educ1 sr_vign_4_t_educ
label var sr_vign_4_t_educ "Education (1=College degree; 0=HS diploma)"

forvalues i=24/25{
local a=`i'-21

tab vote`i', mis gen(sr_vign_`a'_t_party)
drop sr_vign_`a'_t_party1 
rename sr_vign_`a'_t_party2 vc_vign_`a'_t_dem
rename sr_vign_`a'_t_party3 vc_vign_`a'_t_rep
gen sr_vign_`a'_t_sameparty=0
gen sr_vign_`a'_t_opposingparty=0
replace sr_vign_`a'_t_sameparty=1 if (vc_vign_`a'_t_dem==1 & pid3==-1) | (vc_vign_`a'_t_rep==1 & pid3==1) 
replace sr_vign_`a'_t_opposingparty=1 if (vc_vign_`a'_t_dem==1 & pid3==1) | (vc_vign_`a'_t_rep==1 & pid3==-1) 
gen sr_vign_`a'_t_ind_dem=(pid3==0) & (vc_vign_`a'_t_dem==1)
gen sr_vign_`a'_t_ind_rep=(pid3==0) & (vc_vign_`a'_t_rep==1)
label var sr_vign_`a'_t_sameparty "From Preferred Party"
label var sr_vign_`a'_t_opposingparty "From Opposing Party"
label var sr_vign_`a'_t_ind_dem "Independent Presented with Democrat"
label var sr_vign_`a'_t_ind_rep "Independent Presented with Republican"
}

*drop cases where pid is missing
drop if pid3==.

** Recode Outcome Measures to scale from -3 to 3 with higher values indicating more favorable evaluations.
foreach i in yala22* yala23* yala24* yala25* yala97* yala98* yala99* yala100* {
recode `i' (1=3) (2=2) (3=1) (4=0) (5=-1) (6=-2) (7=-3) (8=.)
}
** Generate mean indices for outcomes
egen sr_vign_1_eval=rmean(yala22*)
egen sr_vign_2_eval=rmean(yala23*)
egen sr_vign_3_eval=rmean(yala24*)
egen sr_vign_4_eval=rmean(yala25*)

egen sr_single_1_eval=rmean(yala97*)
egen sr_single_2_eval=rmean(yala98*)
egen sr_single_3_eval=rmean(yala99*)
egen sr_single_4_eval=rmean(yala100*)

forvalues i=1/4{
replace sr_vign_`i'_eval=(sr_vign_`i'_eval+3)/6
replace sr_single_`i'_eval=(sr_single_`i'_eval+3)/6
label var sr_vign_`i'_eval "Evaluation: Vignette `i' (0 to 1)"
label var sr_single_`i'_eval "Evaluation: Single Item `i' (0 to 1)"
}

** Set sample
**** NOTE: 9 cases that did not provide valid responses to the items used in the "single item vignettes" analysis reported in the 
**** discussion section of the manuscript are excluded from the analysis
reg sr_vign_*_eval sr_single_*_eval r_black r_hispanic r_other age age2 female religatt interest educ trustgov income incomemis ideolD* pidD*, r
drop if e(sample)==0

*** TEST OUTCOME INDEX RELIABILITIES
foreach i in yala22* yala23* yala24* yala25* yala97* yala98* yala99* yala100*{
alpha `i'
}

*** SUMMARY STATS
outsum r_white r_black r_hispanic r_other age female educ income incomemis pid ideol religatt interest trustgov [aw=v200] using "tables\tableA1_summary", bracket replace ctitle(2009 CCES)

*** BALANCE CHECKS
forvalues i=1/2{
gen condition_vign_`i'=0
local count=1
foreach v of varlist sr_vign_`i'_t* {
replace condition_vign_`i'=condition_vign_`i'+(`count'*`v')
local count=`count'*2
}
}

forvalues i=1/2{
*mlogit condition_single_`i' r_black r_hispanic r_other age age2 female religatt interest educ trustgov income incomemis ideol pid, r
*disp chi2tail(e(df_m), e(chi2))
mlogit condition_vign_`i' r_black r_hispanic r_other age age2 female religatt interest educ trustgov income incomemis ideol pid, r
disp chi2tail(e(df_m), e(chi2))
}

foreach i in r_black r_hispanic r_other age age2 female religatt interest educ trustgov income incomemis ideol pid {
test `i'
}


*** OUTPUT VIGNETTE ANALYSIS (Regressions)
forvalues i=1/2{
reg sr_vign_`i'_eval sr_vign_`i'_t* r_black r_hispanic r_other age age2 female religatt interest educ trustgov income incomemis ideolD* pidD* [aw=v200], r
if `i'==1{
sum sr_vign_`i'_eval [aw=v200]
outreg sr_vign_1_t_always sr_vign_1_t_usually sr_vign_1_t_never sr_vign_1_t_tax sr_vign_1_t_educ using "tables\table2_vignette", addstat("Standard Deviation of Outcome",r(sd)) se bracket replace rdec(3) adec(3)
outreg sr_vign_1_t_always sr_vign_1_t_usually sr_vign_1_t_never sr_vign_1_t_tax sr_vign_1_t_educ  r_black r_hispanic r_other age age2 female religatt interest educ trustgov income incomemis ideolD* pidD* using "tables\tableA2_fullvignette", se bracket replace rdec(3)
}
else{
sum sr_vign_`i'_eval [aw=v200]
outreg sr_vign_`i'_t* using "tables\table2_vignette", addstat("Standard Deviation of Outcome",r(sd)) se bracket append rdec(3) adec(3)
outreg using "tables\tableA2_fullvignette", se bracket append rdec(3)
}
}
*unweighted
forvalues i=1/2{
reg sr_vign_`i'_eval sr_vign_`i'_t* r_black r_hispanic r_other age age2 female religatt interest educ trustgov income incomemis ideolD* pidD*, r
if `i'==1{
outreg sr_vign_`i'_t* using "tables\tableA3_vignette_robust", se bracket replace rdec(3) ctitle(unweighted with controls)
}
else{
outreg sr_vign_`i'_t* using "tables\tableA3_vignette_robust", se bracket append rdec(3) ctitle(unweighted with controls)
}
}

*no controls
forvalues i=1/2{
reg sr_vign_`i'_eval sr_vign_`i'_t* [aw=v200], r
if `i'==1{
outreg sr_vign_`i'_t* using "tables\tableA3_vignette_robust", se bracket append rdec(3) ctitle(weighted without controls)
}
else{
outreg sr_vign_`i'_t* using "tables\tableA3_vignette_robust", se bracket append rdec(3) ctitle(weighted without controls)
}
}

*no controls, unweighted
forvalues i=1/2{
reg sr_vign_`i'_eval sr_vign_`i'_t*, r
if `i'==1{
outreg sr_vign_`i'_t* using "tables\tableA3_vignette_robust", se bracket append rdec(3) ctitle(unweighted without controls)
}
else{
outreg sr_vign_`i'_t* using "tables\tableA3_vignette_robust", se bracket append rdec(3) ctitle(unweighted without controls)
}
}

*** TESTS OF COEFFICIENT EQUALITY DISCUSSED IN MANUSCRIPT
reg sr_vign_1_eval sr_vign_1_t* r_black r_hispanic r_other age age2 female religatt interest educ trustgov income incomemis ideolD* pidD* [aw=v200], r
lincom sr_vign_1_t_always-sr_vign_1_t_never
test sr_vign_1_t_always=-sr_vign_1_t_never
test sr_vign_1_t_always=sr_vign_1_t_usually
test (sr_vign_1_t_always-sr_vign_1_t_never)=sr_vign_1_t_tax
test (sr_vign_1_t_always-sr_vign_1_t_never)=sr_vign_1_t_educ

reg sr_vign_2_eval sr_vign_2_t* r_black r_hispanic r_other age age2 female religatt interest educ trustgov income incomemis ideolD* pidD* [aw=v200], r
lincom sr_vign_2_t_always-sr_vign_2_t_never
test sr_vign_2_t_always=-sr_vign_2_t_never
test sr_vign_2_t_always=sr_vign_2_t_usually
test (sr_vign_2_t_always-sr_vign_2_t_never)=sr_vign_2_t_recycle
test (sr_vign_2_t_always-sr_vign_2_t_never)=sr_vign_2_t_current


****TREATMENT INTERACTIONS?
foreach i in sr_vign_1_t_always sr_vign_1_t_never sr_vign_1_t_usually{
gen X1`i'Xeduc=`i'*sr_vign_1_t_educ
gen X1`i'Xtax=`i'*sr_vign_1_t_tax
}

foreach i in sr_vign_2_t_always sr_vign_2_t_never sr_vign_2_t_usually{
gen X2`i'Xcurrent=`i'*sr_vign_2_t_current
gen X2`i'Xrecycle=`i'*sr_vign_2_t_recycle
}


reg sr_vign_1_eval sr_vign_1_t* X1* r_black r_hispanic r_other age age2 female religatt interest educ trustgov income incomemis ideolD* pidD* [aw=v200], r
test X1sr_vign_1_t_alwaysXeduc X1sr_vign_1_t_alwaysXtax X1sr_vign_1_t_neverXeduc X1sr_vign_1_t_neverXtax X1sr_vign_1_t_usuallyXeduc X1sr_vign_1_t_usuallyXtax
test X1sr_vign_1_t_alwaysXeduc X1sr_vign_1_t_neverXeduc X1sr_vign_1_t_usuallyXeduc 
test X1sr_vign_1_t_alwaysXtax X1sr_vign_1_t_neverXtax X1sr_vign_1_t_usuallyXtax

reg sr_vign_2_eval sr_vign_2_t* X2* r_black r_hispanic r_other age age2 female religatt interest educ trustgov income incomemis ideolD* pidD* [aw=v200], r
test X2sr_vign_2_t_alwaysXcurrent X2sr_vign_2_t_alwaysXrecycle X2sr_vign_2_t_neverXcurrent X2sr_vign_2_t_neverXrecycle X2sr_vign_2_t_usuallyXcurrent X2sr_vign_2_t_usuallyXrecycle
test X2sr_vign_2_t_alwaysXcurrent X2sr_vign_2_t_neverXcurrent X2sr_vign_2_t_usuallyXcurrent 
test X2sr_vign_2_t_alwaysXrecycle X2sr_vign_2_t_neverXrecycle X2sr_vign_2_t_usuallyXrecycle

**reports of marginal interaction effect
*FX - never, rather than usually voting
*if doesn't recycle
lincom (sr_vign_2_t_never)-(sr_vign_2_t_usually)
*if recycles
lincom (sr_vign_2_t_never+X2sr_vign_2_t_neverXrecycle)-(sr_vign_2_t_usually+X2sr_vign_2_t_usuallyXrecycle)
*FX - never, rather than always voting
*if doesn't recycle
lincom (sr_vign_2_t_never)-(sr_vign_2_t_always)
*if recycles
lincom (sr_vign_2_t_never+X2sr_vign_2_t_neverXrecycle)-(sr_vign_2_t_always+X2sr_vign_2_t_alwaysXrecycle)
*FX - usually, rather than always voting
*if doesn't recycle
lincom (sr_vign_2_t_usually)-(sr_vign_2_t_always)
*if recycles
lincom (sr_vign_2_t_usually+X2sr_vign_2_t_usuallyXrecycle)-(sr_vign_2_t_always+X2sr_vign_2_t_alwaysXrecycle)



**********
*Effects Different Depending on Political Interest and Turnout?
**********
*Interest Comparisons
gen interest_yes=1 if interest==4
replace interest_yes=0 if interest<4
label var interest_yes "Very Interested in Politics (1=Yes)"

gen interest_no=1 if interest<4
replace interest_no=0 if interest==4
label var interest_no "Not Interested in Politics (1=Yes)"

*Turnout Comparisons
gen turnout_yes=1 if cc09_30==3
replace turnout_yes=0 if cc09_30==2
replace turnout_yes=0 if cc09_30==1
label var turnout_yes "Voted in 2008 (1=Yes)"

gen turnout_no=1 if cc09_30==1 | cc09_30==2
replace turnout_no=0 if cc09_30==3
label var turnout_no "Did Not Vote in 2008 (1=Yes)"


***SEPARATE MODELS BY INTEREST/TURNOUT
forvalues i=1/2{
qui reg sr_vign_`i'_eval sr_vign_`i'_t* r_black r_hispanic r_other age age2 female religatt interest educ trustgov income incomemis ideolD* pidD* [aw=v200] if turnout_no==1, r
disp "Vignette `i'; Non-voters"
lincom (sr_vign_`i'_t_always-sr_vign_`i'_t_never)
qui reg sr_vign_`i'_eval sr_vign_`i'_t* r_black r_hispanic r_other age age2 female religatt interest educ trustgov income incomemis ideolD* pidD* [aw=v200] if turnout_yes==1, r
disp "Vignette `i'; Voters"
lincom (sr_vign_`i'_t_always-sr_vign_`i'_t_never)

qui reg sr_vign_`i'_eval sr_vign_`i'_t* r_black r_hispanic r_other age age2 female religatt interest educ trustgov income incomemis ideolD* pidD* [aw=v200] if interest_no==1, r
disp "Vignette `i'; Low Interest"
lincom (sr_vign_`i'_t_always-sr_vign_`i'_t_never)
qui reg sr_vign_`i'_eval sr_vign_`i'_t* r_black r_hispanic r_other age age2 female religatt interest educ trustgov income incomemis ideolD* pidD* [aw=v200] if interest_yes==1, r
disp "Vignette `i'; High Interest"
lincom (sr_vign_`i'_t_always-sr_vign_`i'_t_never)
}

