set more off
version 12.1
***USE FILE
use data\mturk_replication.dta, clear

** DEMOGRAPHICS
egen pid=rmean(pid_dstr pid_rstr pid_lean)
label var pid "Party ID (-3=S. Dem; 3=S. Rep)"

gen age=2010-yob
label var age "Age (in years)"
gen age2=(age*age)/100
label var age2 "Age-squared/100"

label var educ "Education (1=No HS; 6=post-grad)"
//replace r_other="1" if r_other!=""
//destring r_other, replace
//recast byte r_other

foreach i in white black hispanic asian nativeam mixed other{
 replace r_`i'=0 if r_`i'==.
 replace r_`i'=1 if r_`i'!=0
 label var r_`i' "`i' = 1"
}
replace r_other=r_asian+r_nativeam+r_mixed+r_other
replace r_other=1 if r_other>1
label var r_other "Other race=1"
label var r_white "White = 1"
label var r_black "Black = 1"
label var r_hispanic "Hispanic = 1"
drop r_asian r_nativeam r_mixed 

label var female "Female=1"

*** SUMMARY STATISTICS
outsum r_white r_black r_hispanic r_other age female educ pid using "tables\tableA1_summary", bracket append ctitle(Mechanical Turk Sample)

*** RANKING
** Generate variable to record the ranking for each descriptor.
foreach i in color_green color_red tip_well tip_poorly vote_always vote_never pid_democrat pid_republican job_doctor job_lawyer smoke_no smoke_yes tidy_messy tidy_organized weight_obese weight_inshape taxes_late taxes_ontime recycle_yes recycle_no donate_yes donate_no speed_2tix speed_notix{
 gen rank_`i'=.
}

* Build ranking scores 
foreach i in a1 a2 a3 a4 a5 a6 b1 b2 b3 b4 b5 b6{
 replace rank_color_green=rank`i'_score if rank`i'=="Their favorite color is green"
 replace rank_color_red=rank`i'_score if rank`i'=="Their favorite color is red"
 replace rank_tip_well=rank`i'_score if rank`i'=="They always tip waiters and waitresses more than 10%"
 replace rank_tip_poorly=rank`i'_score if rank`i'=="They never tip waiters and waitresses more than 10%"
 replace rank_vote_always=rank`i'_score if rank`i'=="They always vote in presidential elections"
 replace rank_vote_never=rank`i'_score if rank`i'=="They never vote in presidential elections"
 replace rank_pid_democrat=rank`i'_score if rank`i'=="They are a Democrat"
 replace rank_pid_republican=rank`i'_score if rank`i'=="They are a Republican"
 replace rank_job_doctor=rank`i'_score if rank`i'=="They are a doctor"
 replace rank_job_lawyer=rank`i'_score if rank`i'=="They are a personal injury lawyer"
 replace rank_smoke_no=rank`i'_score if rank`i'=="They are a non-smoker"
 replace rank_smoke_yes=rank`i'_score if rank`i'=="They are a smoker"
 replace rank_tidy_messy=rank`i'_score if rank`i'=="They are messy"
 replace rank_tidy_organized=rank`i'_score if rank`i'=="They are organized"
 replace rank_donate_no=rank`i'_score if rank`i'=="They do not donate any of their income to charity"
 replace rank_donate_yes=rank`i'_score if rank`i'=="They donate 5% of their income to charity"
 replace rank_speed_2tix=rank`i'_score if rank`i'=="They have gotten 2 speeding tickets in the last year"
 replace rank_speed_notix=rank`i'_score if rank`i'=="They have not gotten a speeding ticket in the last year"
 replace rank_weight_obese=rank`i'_score if rank`i'=="They are obese"
 replace rank_weight_inshape=rank`i'_score if rank`i'=="They keep in shape"
 replace rank_taxes_late=rank`i'_score if rank`i'=="They pay their taxes late"
 replace rank_taxes_ontime=rank`i'_score if rank`i'=="They pay their taxes on time"
 replace rank_recycle_no=rank`i'_score if rank`i'=="They do not recycle"
 replace rank_recycle_yes=rank`i'_score if rank`i'=="They recycle"
}

* Convert straight PID indicators to "from same/other party"
gen rank_pid_same=rank_pid_republican if pid>0
replace rank_pid_same=rank_pid_democrat if pid<0

gen rank_pid_other=rank_pid_republican if pid<0
replace rank_pid_other=rank_pid_democrat if pid>0

* Labels
label var rank_color_green "Ranking: Favorite color green"
label var rank_color_red "Ranking: Favorite color red"
label var rank_tip_well "Ranking: Tip >10%"
label var rank_tip_poorly "Ranking: Tip <=10%"
label var rank_vote_always "Ranking: Always vote"
label var rank_vote_never "Ranking: Never vote"
label var rank_pid_democrat "Ranking: Democrat"
label var rank_pid_republican "Ranking: Republican"
label var rank_job_doctor "Ranking: Doctor"
label var rank_job_lawyer "Ranking: Personal injury lawyer"
label var rank_smoke_no "Ranking: Non-smoker"
label var rank_smoke_yes "Ranking: Smoker"
label var rank_tidy_messy "Ranking: Messy"
label var rank_tidy_organized "Ranking: Organized"
label var rank_donate_no "Ranking: Don't donate"
label var rank_donate_yes "Ranking: Donate 5%"
label var rank_speed_2tix "Ranking: Two speeding tickets"
label var rank_speed_notix "Ranking: No speeding tickets"
label var rank_weight_obese "Ranking: Obese"
label var rank_weight_inshape "Ranking: In shape"
label var rank_taxes_late "Ranking: Taxes late"
label var rank_taxes_ontime "Ranking: Taxes on time"
label var rank_recycle_yes "Ranking: Recycles"
label var rank_recycle_no "Ranking: Does not recycle"
label var rank_pid_same "Ranking: Same PID"
label var rank_pid_other "Ranking: Opposing PID"

*********************************************************
*Calculate bootstrapped differences in rankings broad behavior measures
*********************************************************
** Get means/SEs for comparisons to political behaviors
*Get N for difference in difference tests
 count if allocation_ranking=="ranking"
 local allocation_n=r(N)
*Voting
qui ttest rank_vote_always==rank_vote_never if allocation_ranking=="ranking", unequal unpai
 local rank_diff_vote_mean=r(mu_2)-r(mu_1)
 qui bootstrap mean=(r(mu_2)-r(mu_1)), reps(1000) seed(321): ttest rank_vote_always==rank_vote_never if allocation_ranking=="ranking", unequal unpai
 matrix temp1=e(se)
 local rank_diff_vote_sd=temp1[1,1]*sqrt(`allocation_n')
*Partisanship
qui ttest rank_pid_same==rank_pid_other if allocation_ranking=="ranking", unequal unpai
 local rank_diff_pid_mean=r(mu_2)-r(mu_1)
 qui bootstrap mean=(r(mu_2)-r(mu_1)), reps(1000) seed(321): ttest rank_pid_same==rank_pid_other if allocation_ranking=="ranking", unequal unpai
 matrix temp1=e(se)
 local rank_diff_pid_sd=temp1[1,1]*sqrt(`allocation_n')

**** CALCULATE RANK DIFFERENCES
* Open CSV file to write Figure 1 Data to
file open myfile using "tables\figure1_ranking_data.csv", write replace 
file write myfile "Behavior,Upper Bound,Lower Bound,Difference in Rank,DID (p-value relative to voting Diff)" _n

* Specify variables to cycle through
local varnames="rank_color_red rank_color_green rank_vote_always rank_vote_never rank_weight_inshape rank_weight_obese rank_job_doctor rank_job_lawyer rank_pid_same rank_pid_other rank_tip_well rank_tip_poorly"
* Pair names
local diffnames="Red-Green; Always-Never Vote; In-Shape-Obese; Doctor-PI Lawyer; Same PID-Other; Tip Well-Poorly; No Speeding-Two Tickets; Taxes On Time-Late; Non-Smoker-Smoker; Donates-Doesn't; Recycles-Doesn't; Organized-Messy"
* Loop through 12 behavior pairs
forvalues i = 1(1)12 {
 gettoken first varnames : varnames
 gettoken second varnames : varnames
 gettoken name diffnames : diffnames, parse(";") 
 ttest `first'== `second' if allocation_ranking=="ranking", unequal unpai
 local diff=r(mu_2)-r(mu_1)

 di "Working on `first'== `second'"
 * Bootstrapped unpaired t-test, unequal variance
 bootstrap mean=(r(mu_2)-r(mu_1)), reps(1000) seed(321): ttest `first'== `second' if allocation_ranking=="ranking", unequal unpai
 * grab matrices
 matrix temp2=e(ci_percentile)
 matrix temp3=e(se)
 local lb=temp2[1,1]
 local ub=temp2[2,1]
 local sd=temp3[1,1]*sqrt(`allocation_n')
 * This is to calculate difference in difference, relative to voting always versus never, for comparison. diffdiff_vote_p is not used in Figure 1
 qui ttesti `allocation_n' `rank_diff_vote_mean' `rank_diff_vote_sd' `allocation_n' `diff' `sd', uneq
 local diffdiff_vote=(r(mu_2)-r(mu_1))
 local diffdiff_vote_p=r(p)

 * write name, upper bound, lower bound, and difference of means to row in CSV
 file write myfile "`name',`ub',`lb',`diff',`diffdiff_vote_p'" _n
 gettoken name diffnames : diffnames, parse(";") 

 * list of variables too long above, thus need this to continue through all pairs
 if "`second'" == "rank_tip_poorly" {
  local varnames="rank_speed_notix rank_speed_2tix rank_taxes_ontime rank_taxes_late rank_smoke_no rank_smoke_yes rank_donate_yes rank_donate_no rank_recycle_yes rank_recycle_no rank_tidy_organized rank_tidy_messy"
 }
}
*Close file
file close myfile

*********************************************************
*Calculate bootstrapped mean rankings broad behavior measures
*********************************************************
* Open CSV file to write to
file open myfile using "tables\figureA1_ranking_means_data.csv", write replace 
file write myfile "Behavior,Upper Bound,Lower Bound,Mean" _n

* Specify variables to cycle through
local varnames="rank_job_doctor rank_tidy_organized rank_donate_yes rank_recycle_yes rank_smoke_no rank_pid_same rank_weight_inshape rank_taxes_ontime rank_tip_well rank_vote_always rank_speed_notix rank_color_red rank_job_lawyer rank_color_green"
* Loop through 24 behaviors 
forvalues i = 1(1)24 {
 gettoken behavior varnames : varnames
 local name : variable label `behavior'
 local name =subinstr("`name'","Ranking: ","",.)

 * Get mean
 qui summ `behavior' if allocation_ranking=="ranking"
 local diff=r(mean)

 di "Working on `behavior'"
 * Bootstrapped confidence interval for difference, not bias corrected (just percentile)
 qui bootstrap mean=r(mean), reps(1000) seed(321): summ `behavior' if allocation_ranking=="ranking"
 * grab matrices
 matrix temp2=e(ci_percentile)
 local lb=temp2[1,1]
 local ub=temp2[2,1]

 * write name, upper bound, lower bound, and difference of means to row in CSV
 file write myfile "`name',`ub',`lb',`diff'" _n

 * list of variables too long above, thus need this to continue through all pairs
 if "`behavior'" == "rank_color_green" {
  local varnames="rank_weight_obese rank_vote_never rank_pid_other rank_donate_no rank_tip_poorly rank_speed_2tix rank_taxes_late rank_recycle_no rank_smoke_yes rank_tidy_messy"
 }
}
*Close file
file close myfile

******************

*********************************************************
*Analysis of contribution behavior decisions
*********************************************************

*** ALLOCATION 
* Binary indicators 
gen color_treat=1 if alloc_color_treat=="green" 
replace color_treat=0 if alloc_color_treat=="red" 
gen recycle_treat=1 if alloc_recycle_treat=="does not recycle" 
replace recycle_treat=0 if alloc_recycle_treat=="recycles" 
gen vote_treat=1 if alloc_vote_treat=="never" 
replace vote_treat=0 if alloc_vote_treat=="always" 

foreach i in alloc_color_red alloc_color_green alloc_recycle_yes alloc_recycle_no alloc_vote_yes alloc_vote_no{
 gen `i'_binary=0 if `i'==0
 replace `i'_binary=1 if `i'>0 & `i'!=. 
}

egen alloc_color=rmean(alloc_color_green alloc_color_red)
egen alloc_recycle=rmean(alloc_recycle_yes alloc_recycle_no)
egen alloc_vote=rmean(alloc_vote_yes alloc_vote_no)
egen alloc_color_binary=rmean(alloc_color_green_binary alloc_color_red_binary)
egen alloc_recycle_binary=rmean(alloc_recycle_yes_binary alloc_recycle_no_binary)
egen alloc_vote_binary=rmean(alloc_vote_yes_binary alloc_vote_no_binary)

label var alloc_color_red "Allocation: Favorite color red"
label var alloc_color_green "Allocation: Favorite color green"
label var alloc_recycle_yes "Allocation: Recycles"
label var alloc_recycle_no "Allocation: Doesn't Recycle"
label var alloc_vote_yes "Allocation: Always votes"
label var alloc_vote_no "Allocation: Never votes"

label var alloc_color_red_binary "Allocation: Favorite color red (Binary)"
label var alloc_color_green_binary "Allocation: Favorite color green (Binary)"
label var alloc_recycle_yes_binary "Allocation: Recycles (Binary)"
label var alloc_recycle_no_binary "Allocation: Doesn't Recycle (Binary)"
label var alloc_vote_yes_binary "Allocation: Always votes (Binary)"
label var alloc_vote_no_binary "Allocation: Never votes (Binary)"

label var alloc_color "Allocation: Favorite color"
label var alloc_recycle "Allocation: Recycling"
label var alloc_vote "Allocation: Voting"
label var alloc_color_binary "Allocation: Favorite color (Binary)"
label var alloc_recycle_binary "Allocation: Recycling (Binary)"
label var alloc_vote_binary "Allocation: Voting (Binary)"

*** Make table of mean estimates
gen alloc_all=alloc_color~=. & alloc_recycle~=. & alloc_vote~=. 
* means conditional on giving anything
foreach i in color_red color_green recycle_yes recycle_no vote_yes vote_no {
sum alloc_`i' if alloc_`i'_binary==1 
}
* Open CSV file to write to
file open myfile using "tables\table3_allocation.csv", write replace 
file write myfile "Item,Any Allocation, Allocation Amount" _n
* Loop through 3 experiments
local diffnames="Favorite Color: Red - Green ; Recycles: Yes - No ; Votes: Always - Never"
foreach i in color recycle vote {
 gettoken name diffnames : diffnames, parse(";") 

 di "Working on `i'"
 *Difference in proportions
 qui prtest alloc_`i'_binary if alloc_all==1, by(`i'_treat)
 local diff=round((r(P_1)-r(P_2)),.001)

 * Bootstrapped confidence interval for difference, not bias corrected (just percentile)
 qui bootstrap meandiff=(r(P_1)-r(P_2)), reps(1000) seed(321):  prtest alloc_`i'_binary if alloc_all==1, by(`i'_treat)
 * grab matrices
 matrix temp2=e(ci_percentile)
 local lb=round(temp2[1,1],.001)
 local ub=round(temp2[2,1],.001)

 qui ttest alloc_`i' if alloc_all==1, by(`i'_treat)
 local diff_2=round((r(mu_1)-r(mu_2)),.001)

 * Bootstrapped test of equality means ($)
 qui bootstrap meandiff=(r(mu_1)-r(mu_2)), reps(1000) seed(321): ttest alloc_`i' if alloc_all==1, by(`i'_treat)
 * grab matrices
 matrix temp4=e(ci_percentile)
 local lb_2=round(temp4[1,1],.001)
 local ub_2=round(temp4[2,1],.001)

 * write 2 rows, first w/name and differences, second with CIs
 file write myfile "`name', `diff', `diff_2'" _n
 file write myfile ", [`lb';`ub'],[`lb_2';`ub_2']" _n

 gettoken name diffnames : diffnames, parse(";") 
}
*Close file
file close myfile
** t-tests for footnote
foreach i in color recycle vote {
 bootstrap meandiff=(r(P_1)-r(P_2)), reps(1000) seed(321):  prtest alloc_`i'_binary if alloc_all==1, by(`i'_treat)
 bootstrap meandiff=(r(mu_1)-r(mu_2)), reps(1000) seed(321): ttest alloc_`i' if alloc_all==1, by(`i'_treat)
}

**TABLE 3 Panel B
sum alloc_color_red_binary alloc_color_green_binary alloc_recycle_yes_binary alloc_recycle_no_binary alloc_vote_yes_binary alloc_vote_no_binary, sep(0)
sum alloc_color_red alloc_color_green alloc_recycle_yes alloc_recycle_no alloc_vote_yes alloc_vote_no, sep(0)
