
clear
use CCES2009_SingleItem_CountyTO.dta 

gen treatment=.
replace treatment=1 if sr_single_3_t_vote1==1
replace treatment=0 if sr_single_3_t_vote3==1
label var treatment "Treatment (1=Always, 0=Never)"
keep if treatment~=.

gen voteeval= sr_single_3_eval if treatment==1
gen nonvoteeval= sr_single_3_eval if treatment==0

local numbins=20

xtile turnoutxtile=county_to, nquantiles(`numbins')

collapse (min) minto= county_to (max) maxto=county_to (mean) voteeval nonvoteeval (count) n=county_to, by(turnoutxtile)

gen netbenvote= voteeval- nonvoteeval
gen label = string(100*minto,"%9.1f") + " to " +  string(100*maxto,"%9.1f") + "%"

*Label xaxis
 forvalues ctr = 1/`numbins' {
  local temp=label[`ctr']
  label define xaxislbl `ctr' "`temp'", add
}

label values turnoutxtile xaxislbl
label var turnoutxtile "County turnout, `numbins' quantiles"

regress netbenvote turnoutxtile, robust
local beta=string(_b[turnoutxtile],"%9.3f")
local se=string(_se[turnoutxtile],"%9.3f")
local notetext="In N=`numbins' OLS regression predicting Diff. in social evaluations across county turnout quantiles (1 to `numbins'), coefficient=`beta' and SE=`se'." 
qui summ n

twoway (scatter netbenvote turnoutxtile) (lfit netbenvote turnoutxtile), ytitle("Diff. in Social Evaluation, Always Voting minus Never") ytitle(, size(small)) ylabel(1(.5)2.5) xlabel(1(1)`numbins', labsize(vsmall) angle(forty_five) valuelabel) xtitle(,size(small)) legend(off) caption("Avg. number of observations per county turnout quantiles is `r(mean)'", size(vsmall) span) note("`notetext'", size(vsmall) span) scheme(s1mono) title("Figure 2: Effect of County Turnout on Differences in Evaluations", size(medsmall)) subtitle("of Voters and Non-Voters, CCES Single Item Experiments", size(medsmall))

graph export "Figure2.pdf", as(pdf) replace
graph export "Figure2.eps", as(eps) replace

